@@ -1,7 +1,6 @@
 package Mic::Implementation;
 
 use strict;
-use Mic::_Guts;
 use Package::Stash;
 use Params::Validate qw(:all);
 
@@ -51,7 +50,7 @@ sub add_sym {
     $arg->{slot_offset}{$slot} = $sym_val;
 
     $stash->add_symbol(
-        sprintf('&%s', uc $slot),
+        sprintf('&%s', $slot),
         sub () { $sym_val }
     );
 }
