@@ -1,17 +1,17 @@
 package Example::Synopsis::HashSet;
 
-use Mic::Implementation
+use Mic::Impl
     has => { SET => { default => sub { {} } } },
 ;
 
 sub has {
     my ($self, $e) = @_;
-    exists $self->{$SET}{$e};
+    exists $self->[SET]{$e};
 }
 
 sub add {
     my ($self, $e) = @_;
-    ++$self->{$SET}{$e};
+    ++$self->[SET]{$e};
 }
 
 1;
